package com.javaseleniumtemplate.pages;

import com.javaseleniumtemplate.bases.PageBase;
import org.openqa.selenium.By;
import org.openqa.selenium.Keys;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.interactions.Actions;
import org.testng.Assert;
import org.testng.annotations.Test;

public class GrupoServicosPage extends PageBase {

    By botaoMenu = By.xpath("//div[@class='bars']");
    By campoPesquisar = By.xpath("//section[@class='zh-container-search-menu']//input[@type='text']");
    By opcaoTelaGrupoServicos = By.xpath("//span[text() = 'Grupo de Serviços']");

    By botaoAdicionar = By.xpath("//div[@class=\"zh-footer-center\"]");
    By botaoSalvar = By.xpath("//div[@class=\"zh-footer-right\"]");
    By botaoExcluir = By.xpath("//div[@class=\"zh-footer-center\"]");

    By campoCodigo = By.id("CDGRUPSERV");
    By campoNome = By.id("NMGRUPSERV");
    By mensagemObrigatorioCodigo = By.xpath("//div[@data-zh-id=\"9743825571937903742737\"]//div[@class=\"zh-validation\"]/span");
    By mensagemObrigatorioNome = By.xpath("//div[@data-zh-id=\"9743825571294891131738\"]//div[@class=\"zh-validation\"]/span");

    By checkBoxGrupo = By.xpath("//div[@id=\"grid-974382557381890778736\"]//div[@class=\"body-content\"]/div[7]//div[@data-zh-field-name=\"__CHECKBOX\"]/span");
    By codigoGrupo = By.xpath("//div[@id=\"grid-974382557381890778736\"]//div[@class=\"body-content\"]/div[7]//div[@data-zh-field-name=\"CDGRUPSERV\"]/span");
    By nomeGrupo = By.xpath("//div[@id=\"grid-974382557381890778736\"]//div[@class=\"body-content\"]/div[7]//div[@data-zh-field-name=\"NMGRUPSERV\"]/span");

    By mensagemCantoSuperiorDireito = By.xpath("//*[@class=\"zh-notification-messages\"]//span[@class=\"notification-message-text\"]");
    By mensagemAlerta = By.xpath("//section[@class=\"zh-container-alert\"]//div[@class=\"zh-alert-scroll\"]/p");
    By botaoSim = By.xpath("//section[@class=\"zh-container-alert\"]//button[@data-zh-id=\"zh-footer-alert-button-0\"]");
    By botaoOk = By.xpath("//section[@class=\"zh-container-alert\"]//button[@type=\"submit\"]");

    By codigoGrupoParaVerificarServico = By.xpath("//div[@id=\"grid-974382557381890778736\"]//div[@class=\"body-content\"]/div[6]//div[@data-zh-field-name=\"CDGRUPSERV\"]/span");
    By abaServico = By.xpath("//div[@class=\"zh-tab-wrapper\"]//label[@class=\"zh-tab-cell\"]//a[text() = 'Serviços']");
    By codigoServico = By.xpath("//div[@id=\"grid-9743825574259211496414\"]//div[@class=\"body-content\"]/div[1]//div[@data-zh-field-name=\"CDSERVFILI\"]/span");
    By nomeServico = By.xpath("//div[@id=\"grid-9743825574259211496414\"]//div[@class=\"body-content\"]/div[1]//div[@data-zh-field-name=\"NMSERVICO\"]/span");
    By campoOrdenacaoTransporteServico = By.xpath("//div[@id=\"grid-9743825574259211496414\"]//div[@class=\"body-content\"]/div[1]//div[@data-zh-field-name=\"NRORDSERVTRANSP\"]//div[@class=\"editable-content\"]");
    By inputOrdenacaoTransporteServico = By.xpath("//div[@id=\"grid-9743825574259211496414\"]//div[@class=\"body-content\"]/div[1]//div[@data-zh-field-name=\"NRORDSERVTRANSP\"]//div[@class=\"editable-content\"]/input");
    By botaoSalvarAlteracoes = By.xpath("//div[@class=\"zh-footer-right\"]");

    public void acessarTela() {
        tempoParaAguardarTelaInicial();
        waitForElement(botaoMenu);
        click(botaoMenu);
        sendKeys(campoPesquisar, "Grupo de Serviços");
        click(opcaoTelaGrupoServicos);
    }

    public void adicionarGrupo() {
        click(botaoAdicionar);
        sendKeys(campoCodigo, "7");
        sendKeys(campoNome, "VENDAS");
        click(botaoSalvar);

        //dados do grupo adicionado
        String codigo = getText(codigoGrupo);
        String nome = getText(nomeGrupo);

        Assert.assertEquals(codigo, "007", "Verificação do código");
        Assert.assertEquals(nome, "VENDAS", "Verificação do nome");
    }

    public void editarGrupo() {
        tempo();
        Actions actions = new Actions(driver);
        actions.click(driver.findElement(nomeGrupo)).build().perform();
        tempo();
        actions.sendKeys("VENDAS CARAS").build().perform();
        tempo();
        actions.sendKeys(Keys.ENTER).build().perform();
        click(botaoSalvar);
        tempo();

        //nome do grupo editado
        String nome = getText(nomeGrupo);
        Assert.assertEquals(nome, "VENDAS CARAS", "Verificação do nome do grupo editado");
    }

    public void excluir() {
        tempo();
        click(checkBoxGrupo);
        click(botaoExcluir);

        String mensagem = getText(mensagemAlerta);
        Assert.assertEquals(mensagem, "Deletar o(s) registro(s)?", "Verificação mensagem alerta da exclusão");
        click(botaoSim);
        tempo();

        String mensagemExcluidoSucesso = getText(mensagemCantoSuperiorDireito);
        Assert.assertEquals(mensagemExcluidoSucesso, "Excluído com sucesso.", "Verificação da mensagem de excluído om sucesso, após a exclusão do grupo");
    }

    public void camposObrigatorios() {
        tempo();
        click(botaoAdicionar);
        tempo();
        click(botaoSalvar);

        //mensagem de campo obrigatório encontrada no código e nome
        String mensagemCodigo = getText(mensagemObrigatorioCodigo);
        String mensagemNome = getText(mensagemObrigatorioNome);

        String mensagemEsperada = "Campo obrigatório";
        Assert.assertEquals(mensagemCodigo, mensagemEsperada, "Verificação da mensagem de campo obrigatório, no campo código");
        Assert.assertEquals(mensagemNome, mensagemEsperada, "Verificação da mensagem de campo obrigatório, no campo nome");
    }

    public void adicionarCodigoExistente() {
        click(botaoAdicionar);
        sendKeys(campoCodigo, "1");
        sendKeys(campoNome, "VENDAS");
        click(botaoSalvar);

        //mensagem alerta de código já existente
        String mensagem = getText(mensagemAlerta);
        String mensagemEsperada = "Impossível adicionar. Registro já existe.";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem de alerta exibida após tentar adicionar um código já existente");
        click(botaoOk);
    }

    public void verificarAbaServico() {
        tempo();
        click(codigoGrupoParaVerificarServico);
        click(abaServico);

        Actions actions = new Actions(driver);
        WebElement element = driver.findElement(campoOrdenacaoTransporteServico);

        //dados do serviço encontrado na aba serviço
        String encCodigo = getText(codigoServico);
        String encNome = getText(nomeServico);
        //valores esperados para o serviço
        String expCodigo = "00005";
        String expNome = "REFEIÇÕES TRANSPORTADAS";
        Assert.assertEquals(encCodigo, expCodigo, "Verificação do código do serviço encontrado na aba serviço");
        Assert.assertEquals(encNome, expNome, "Verificação do nome do serviço encontrado na aba serviço");

        actions.moveToElement(element).click();
        actions.sendKeys(element, "LETRAS");
        actions.sendKeys(Keys.ENTER).build().perform();
        //mensagem exibida no canto superior direito quando após tentar adicionar letras no campo de ordenação
        String mensagemExibida = getText(mensagemCantoSuperiorDireito);
        String mensagemEsperada = "Valor deve ser um número";
        Assert.assertEquals(mensagemExibida, mensagemEsperada, "Verificação da mensagem exibida no canto superior direito quando após tentar adicionar letras no campo de ordenação");

        tempo();
        actions.moveToElement(element).click();
        actions.sendKeys(element, "+-*/");
        actions.sendKeys(Keys.ENTER).build().perform();
        //mensagem exibida no canto superior direito quando após tentar adicionar caracteres especiais no campo de ordenação
        mensagemExibida = getText(mensagemCantoSuperiorDireito);
        mensagemEsperada = "Valor deve ser um número";
        Assert.assertEquals(mensagemExibida, mensagemEsperada, "Verificação da mensagem exibida no canto superior direito quando após tentar adicionar caracteres especiais no campo de ordenação");

        tempo();
        actions.moveToElement(element).click().build().perform();
        tempo();
        actions.sendKeys("2").build().perform();
        tempo();
        actions.sendKeys(Keys.ENTER).build().perform();
        tempo();
        boolean mensagemApresentadaNoCantoDaTela = returnIfElementExists(mensagemCantoSuperiorDireito);
        Assert.assertEquals(mensagemApresentadaNoCantoDaTela, false, "Verificar se é apresentada alguma mensagem no canto superor da tela, após adicionar um número no campo ordenação");

        tempo();
        click(botaoSalvarAlteracoes);
        tempo();
        String encOrdencao = driver.findElement(inputOrdenacaoTransporteServico).getAttribute("value");
        String expOrdenacao = "2";
        Assert.assertEquals(encOrdencao, expOrdenacao, "Verificar se o valor salvo no campo ordenação é o mesmo informado pelo usuário");

        tempo();
        actions.moveToElement(element).click().build().perform();
        tempo();
        actions.sendKeys(Keys.BACK_SPACE).build().perform();
        tempo();
        actions.sendKeys(Keys.ENTER).build().perform();

        click(botaoSalvarAlteracoes);
        encOrdencao = driver.findElement(inputOrdenacaoTransporteServico).getAttribute("value");
        expOrdenacao = "";
        Assert.assertEquals(encOrdencao, expOrdenacao, "Verificar se o valor da ordenação foi apagado e o mesmo está vazio");

        tempo();
        actions.moveToElement(element).click().build().perform();
        tempo();
        actions.sendKeys("5").build().perform();
        tempo();
        actions.sendKeys(Keys.ENTER).build().perform();
        tempo();
        click(botaoSalvarAlteracoes);
    }

}
